server {
    listen       80;
    server_name  conf_HOSTNAME;
    root   /var/www/html/conf_IMAGE;
    index index.php;

    set $no_cache 0;
    if ($request_method = POST)
    {
        set $no_cache 1;
    }
    if ($request_uri ~* "/(wp-admin/|wp-login.php)")
    {
        set $no_cache 1;
    }
    if ($http_cookie ~* "comment_author_|wordpress_(?!test_cookie)|wp-postpass_")
    {
        set $no_cache 1;
    }
    add_header X-MicroCache $upstream_cache_status;

    #charset koi8-r;
    #access_log  /var/log/nginx/log/host.access.log  main;

    location / {
	try_files $uri $uri/ /index.php?$args;
    }

    # redirect server error pages to the static page /50x.html
    #
    error_page   500 502 503 504  /50x.html;
    location = /50x.html {
        root   /usr/share/nginx/html;
    }

location ~* /wp-content/.*.php$ {
	deny all;
	access_log off;
	log_not_found off;
}
location ~* /(?:uploads|files)/.*.php$ {
	deny all;
	access_log off;
	log_not_found off;
}

    # pass the PHP scripts to FastCGI server listening on port 9000
    #
    location ~ \.php$ {
	#try_files $uri $uri/ /index.php?q=$uri&$args;
	try_files $uri /index.php;
	fastcgi_split_path_info ^(.+\.php)(/.+)$;

	fastcgi_cache microcache;
	fastcgi_cache_key $scheme$host$request_uri$request_method;
	fastcgi_cache_valid 200 301 302 30s;
	fastcgi_max_temp_file_size 2M;
	fastcgi_cache_use_stale updating error timeout invalid_header http_500;
	fastcgi_pass_header Set-Cookie;
	fastcgi_pass_header Cookie;
	fastcgi_ignore_headers Cache-Control Expires Set-Cookie;
	fastcgi_cache_bypass $no_cache;
	fastcgi_no_cache $no_cache;

	# Variable hack to allow this to run if we don't start all the midlayers
	resolver 127.0.0.11 valid=30s;
	set $upstream_name conf_IMAGE;
        fastcgi_pass   $upstream_name:9000;
        fastcgi_index  index.php;
        fastcgi_param  SCRIPT_FILENAME  /var/www/html/$fastcgi_script_name;
        include        fastcgi_params;
    }

    # deny access to .htaccess files, if Apache's document root
    # concurs with nginx's one
    #
    location ~ /\.ht {
        deny  all;
    }

### FIXME - should break out 301 maps to a config file ###

    # Strava broken links - no leading / from Strava API... thanks, Strava!
    location ~ /avatar/athlete/medium.png$ {
        return 301 https://d3nn82uaxijpm6.cloudfront.net/assets/avatar/athlete/medium-989c4eb40a5532739884599ed662327c.png;
    }
    location ~ /avatar/club/medium.png$ {
        return 301 https://d3nn82uaxijpm6.cloudfront.net/assets/avatar/club/medium-1fc00fdf0e9e5deae40cfa00120fc7c6.png;
    }

    location = /images/Financeit-logo.png {
	return 301 /wp-content/uploads/Financeit-logo.png;
    }

}

