FROM wpd-wordpress:latest
MAINTAINER conf_MAINTAINER

EXPOSE 9000

RUN apk add --no-cache patch unzip curl
# Download and install wp-cli
RUN curl -O https://raw.githubusercontent.com/wp-cli/builds/gh-pages/phar/wp-cli.phar && chmod a+x wp-cli.phar && mv wp-cli.phar /usr/bin/wp

# Create volumes and fix permissions
VOLUME /var/www/html/wp-content/uploads
RUN chmod g+w /var/www/html

# Expand the php file upload size limit
RUN { \
	echo "upload_max_filesize = 50M"; \
	echo "post_max_size = 50M"; \
	echo "memory_limit = 128M"; \
	echo "display_errors = Off"; \
 } >> /usr/local/etc/php/conf.d/custom-php-settings.ini

# Install themes
RUN for theme in conf_WP_THEME; do curl https://downloads.wordpress.org/theme/$theme.zip > /tmp/$theme.zip && unzip -q -o -d /usr/src/wordpress/wp-content/themes/ /tmp/$theme.zip && rm -f /tmp/$theme.zip ; done

ifelse(conf_CHILD_THEME, `', `',
COPY conf_CHILD_THEME.zip /tmp/conf_CHILD_THEME.zip
RUN unzip -q -o -d /usr/src/wordpress/wp-content/themes/ /tmp/conf_CHILD_THEME.zip
)dnl 

# Install plugins
RUN { \
	for plug in conf_WP_PLUGINS; do \
		plug2="$(echo $plug|sed 's/=/./')"; \
		if [ x"$plug" = x"$plug2" ];then \
			plug2=$(curl -s https://wordpress.org/plugins/$plug/ | awk '/"downloadUrl": / { print $2 }' | sed -e 's/.*\///' -e 's/[.]zip",$//'); \
		fi; \
		echo Fetching $plug2; \
		curl -s https://downloads.wordpress.org/plugin/$plug2.zip > /tmp/$plug2.zip && unzip -q -o -d /usr/src/wordpress/wp-content/plugins/ /tmp/$plug2.zip && rm -f /tmp/$plug2.zip; \
	done; \
}

ifelse(conf_LOCAL_PLUGINS, `', `',
copy plugins/*.zip /tmp/
RUN for plugin in conf_LOCAL_PLUGINS; do unzip -q -o -d /usr/src/wordpress/wp-content/plugins/ /tmp/$plugin.zip && rm -f /tmp/$plugin.zip ; done
)dnl

# Apply patches
ifelse(conf_PATCHES, `', `',
COPY patches/*.diff /tmp/
RUN for patch in conf_PATCHES; do cd /usr/src/wordpress/ &&  patch -p0 < /tmp/$patch;done
)dnl 

#COPY wp-version.php /usr/src/wordpress/
ADD https://raw.githubusercontent.com/jinjie/Nagios-WordPress-Update/master/wp-version.php /usr/src/wordpress/
RUN sed -i "s/'127.0.0.1',/'conf_MONITOR_IP',/" /usr/src/wordpress/wp-version.php
RUN chmod 644 /usr/src/wordpress/wp-version.php

RUN { \
	echo 'wp --allow-root core install --url=http://conf_HOSTNAME --title="conf_TITLE" --admin_user=conf_ADMIN_USER --admin_password="conf_ADMIN_PASS" --admin_email=conf_ADMIN_EMAIL'; \
	echo 'wp --allow-root plugin delete hello'; \
	echo 'wp --allow-root plugin delete akismet'; \
	echo 'for plug in conf_WP_PLUGINS conf_LOCAL_PLUGINS; do plug2="$(echo $plug|sed '\''s/=.*//'\'')";wp --allow-root plugin activate $plug2; done'; \
	echo 'if [ x"conf_CHILD_THEME" != x"" ]; then'; \
	echo '  wp --allow-root theme activate conf_CHILD_THEME'; \
	echo 'else'; \
	echo '  wp --allow-root theme activate $(echo conf_WP_THEME|sed '\''s/ .*//'\'')'; \
	echo 'fi'; \
	echo 'wp --allow-root config get --constant=ALLOW_UNFILTERED_UPLOADS >/dev/null 2>&1 || sed -i "\$id""efine('\''ALLOW_UNFILTERED_UPLOADS'\'', true);" /var/www/html/wp-config.php'; \
	echo 'wp --allow-root config get --constant=WP_MEMORY_LIMIT >/dev/null 2>&1 || sed -i "\$id""efine('\''WP_MEMORY_LIMIT'\'', '\''128M'\'');" /var/www/html/wp-config.php'; \
	echo 'wp --allow-root config get --constant=WP_MAX_MEMORY_LIMIT >/dev/null 2>&1 || sed -i "\$id""efine('\''WP_MAX_MEMORY_LIMIT'\'', '\''128M'\'');" /var/www/html/wp-config.php'; \
 } >> /usr/local/bin/configure.local

ifelse(conf_SETUP_SCRIPT, `', `',
COPY conf_SETUP_SCRIPT /tmp/setup
)dnl 

